"""
Agent scaffold modules for Interaxions framework.
"""

from interaxions.scaffolds.base_scaffold import BaseScaffold, BaseScaffoldConfig

__all__ = [
    "BaseScaffold",
    "BaseScaffoldConfig",
]
